**Example 1: ModifyApiIncrement**



Input: 

```
tccli apigateway ModifyApiIncrement --cli-unfold-argument  \
    --ServiceId "service-123" \
    --ApiId "api-123" \
    --BusinessType "OAUTH"
```

Output: 
```
{
    "Response": {
        "RequestId": "c570c877-3c23-4d84-9589-68914dab1507"
    }
}
```

